---
Summary: Allow config for collection
Status: Done
---

# Description

Given that there can be multiple types of collections, it would be useful for
collections to be able to have their own configurations. This means - for
instance, whilst you might have an overall config, a 'User Stories' collection
might require a Cucumber field be set, or an epic field be present where you
don't want that set globally.

In our config file, we add a `collections` collection. Inside that, you can add
settings that only apply to specific collections and their subcollections.

Any lists will be amended to the parent settings:

## Example

```toml
[tool.scrummd]
strict = true
required = ["assignee", "status"]

[tool.scrummd.fields]
status = ["Ready", "Doing", "Done"]

[tool.scrummd.collections.story]
required = ["epic"]

[tool.scrummd.collections.story.fields]
status = ["Testing"]
```

# Cucumber

GIVEN a 'collections' field in the config
WHEN there is a config field
THEN the config field applies to that collection

# Implementation notes

This has only been done for specific fields - so, initially, fields and
requirements.
